@@ -1,12 +1,12 @@
 from __future__ import unicode_literals
 
-from django.core.cache import get_cache, cache
+from django.core.cache import get_cache, cache as default_cache
 from six import string_types
 
 class CachedSerialiser(object):
     '''Mixin to cache per-object serialised data'''
     def __init__(self, *args, **kwargs):
-        cache = getattr(self._meta, 'cache', cache)
+        cache = getattr(self._meta, 'cache', default_cache)
         if isinstance(cache, string_types):
             cache = get_cache(cache)
         self._meta.cache = cache
@@ -18,6 +18,7 @@ class CachedSerialiser(object):
         data = self._meta.cache.get(cache_key)
         if data is None:
             data = super(CachedSerialiser, self).object_deflate(obj, **kwargs)
-            self._meta.cache.set(data, timeout=getattr(self._meta, 'timeout', None))
+            timeout = getattr(self._meta, 'timeout', None)
+            self._meta.cache.set(data, timeout=timeout)
         return data
 
